@@ -343,8 +343,8 @@ class RunConfigurationProvider:
         huml_env.python.user_managed_dependencies = False # Let Azure ML manage dependencies
         huml_env.docker.enabled = True # Use a docker container
         # Set Docker base image to the default CPU-based image
-        DOCKER_ARGUMENTS = ["--gpus", "all"]
-        huml_env.docker.arguments = DOCKER_ARGUMENTS
+        #DOCKER_ARGUMENTS = ["all"]
+        #huml_env.docker.arguments = DOCKER_ARGUMENTS
         huml_env.docker.base_image = "mcr.microsoft.com/azureml/onnxruntime:latest-cuda"
 
         # Add the dependencies to the environment
@@ -352,7 +352,7 @@ class RunConfigurationProvider:
 
         # Register the environment (just in case you want to use it again)
         huml_env.register(workspace=ws)
-        registered_env = Environment.get(ws, 'huml-pipeline-env')
+        #registered_env = Environment.get(ws, 'huml-pipeline-env')
 
         # Create a new runconfig object for the pipeline
         pipeline_run_config = RunConfiguration()
@@ -362,7 +362,7 @@ class RunConfigurationProvider:
         pipeline_run_config.target = compute_target
 
         # Assign the environment to the run configuration
-        pipeline_run_config.environment = registered_env
+        pipeline_run_config.environment = huml_env
 
         return pipeline_run_config
 
